@@ -37,11 +37,11 @@ import urllib.request
 
 
 def get_data_file(module_name, file_basename):
-    """
-    Load data file.
-    :param module_name: name of python module where data file is located
+    """Load data file.
+
+    :param module_name:   name of python module where data file is located
     :param file_basename: name of data file
-    :return: path to data file
+    :return:              path to data file
     """
     try:
         fn = resource_filename(Requirement.parse(module_name), os.path.join("data", file_basename))
@@ -60,11 +60,30 @@ def get_data_file(module_name, file_basename):
         return fn
 
 
-def read_lut_enmap_formatted(file_lut):
+def download_LUT(path_LUT_default):
     """
-    Read MODTRAN LUT.
+    Download LUT file from remote GIT repository.
+
+    :param path_LUT_default: directory where to store the LUT file
+    :return:                 directory of downloaded LUT file
+    """
+    fname = "https://git.gfz-potsdam.de/EnMAP/sicor/-/raw/master/sicor/AC/data/EnMAP_LUT_MOD5_formatted_1nm"
+    urllib.request.urlretrieve(fname, path_LUT_default)
+    if os.path.isfile(path_LUT_default):
+        fn_table = path_LUT_default
+    else:
+        raise FileNotFoundError("Download of LUT file failed. Please download it manually from "
+                                "https://git.gfz-potsdam.de/EnMAP/sicor and store it at /sicor/AC/data/ directory. "
+                                "Otherwise, the AC will not work.")
+
+    return fn_table
+
+
+def read_lut_enmap_formatted(file_lut):
+    """Read MODTRAN LUT.
+
     :param file_lut: path to LUT
-    :return: LUT of atmospheric functions, x and y axes grid points, LUT wavelengths
+    :return:         LUT of atmospheric functions, x and y axes grid points, LUT wavelengths
     """
 
     ndim = 6
@@ -221,17 +240,17 @@ def read_lut_enmap_formatted(file_lut):
 
 @jit(nopython=True)
 def interpol_lut_c(lut1, lut2, xnodes, nm_nodes, ndim, x_cell, vtest, intp_wvl):
-    """
-    Multidimensional LUT interpolation.
-    :param lut1: Path radiance LUT
-    :param lut2: Solar irradiance, spherical albedo and transmittance LUT
-    :param xnodes: Gridpoints for each LUT dimension
+    """Multidimensional LUT interpolation.
+
+    :param lut1:     Path radiance LUT
+    :param lut2:     Solar irradiance, spherical albedo and transmittance LUT
+    :param xnodes:   Gridpoints for each LUT dimension
     :param nm_nodes: Overall number of LUT gridpoints (2**ndim)
-    :param ndim: Dimension of LUT
-    :param x_cell: Interpolation grid (nm_nodes x n_dim)
-    :param vtest: Atmospheric state vector (interpolation point)
+    :param ndim:     Dimension of LUT
+    :param x_cell:   Interpolation grid (nm_nodes x n_dim)
+    :param vtest:    Atmospheric state vector (interpolation point)
     :param intp_wvl: wavelengths for which interpolation should be conducted
-    :return: Path radiance, solar irradiance, spherical albedo and transmittance interpolated at vtest
+    :return:         Path radiance, solar irradiance, spherical albedo and transmittance interpolated at vtest
     """
 
     lim = np.zeros((2, ndim), np.int8)
