@@ -38,10 +38,8 @@ Diagnostic2T = typing.Tuple[NpArrayT, NpArrayT, NpArrayT, NpArrayT]
 CallableT = typing.Callable
 NpOrAnyT = typing.Union[None, NpArrayT]
 FltOrNoneT = typing.Union[None, float]
-InternalOptimizerT = typing.Tuple[NpArrayT, NpArrayT, bool, int,
-                                  NpArrayT, NpOrAnyT, NpOrAnyT,
-                                  FltOrNoneT, FltOrNoneT, FltOrNoneT,
-                                  NpOrAnyT, NpOrAnyT]
+InternalOptimizerT = typing.Tuple[NpArrayT, NpArrayT, bool, int, NpArrayT, NpOrAnyT, NpOrAnyT, FltOrNoneT, FltOrNoneT,
+                                  FltOrNoneT, NpOrAnyT, NpOrAnyT]
 
 EPSIX = np.finfo(float).resolution
 # to be larger than ULP
@@ -61,10 +59,8 @@ RESULT = NT('result',
             'retrieval_noise '
             'smoothing_error')
 
-DEFAULTS = {'se': None, 'sa': None, 'xa': None, 'fg': None,
-            'eps': 0.01, 'jaco': None, 'll': None, 'ul': None,
-            'mi': 10, 'fparam': None, 'jparam': None, 'clip': True,
-            'full': True, 'dx': None, 'gnform': 'n'}
+DEFAULTS = {'se': None, 'sa': None, 'xa': None, 'fg': None, 'eps': 0.01, 'jaco': None, 'll': None, 'ul': None, 'mi': 10,
+            'fparam': None, 'jparam': None, 'clip': True, 'full': True, 'dx': None, 'gnform': 'n'}
 
 
 class OeCoreError(Exception):
@@ -112,10 +108,7 @@ def invert_np(inn: NpArrayT) -> NpArrayT:
 
 
 def invert_pupy(inn: NpArrayT) -> NpArrayT:
-    """
-    pure python inversion of a
-    square matrix
-    """
+    """Pure python inversion of a square matrix."""
     try:
         l, u, p = lu_decomposition(inn)
         il = invert_lower(l)
@@ -130,9 +123,7 @@ def invert_pupy(inn: NpArrayT) -> NpArrayT:
 
 
 def pivot(a: NpArrayT) -> NpArrayT:
-    """
-    returns p , so that p*a is sorted
-    """
+    """Return p, so that p*a is sorted."""
     nr, nc = a.shape
     if nr != nc:
         raise NonSquareMatrixError
@@ -148,12 +139,7 @@ def pivot(a: NpArrayT) -> NpArrayT:
 
 
 def lu_decomposition(ua: NpArrayT) -> typing.Tuple[NpArrayT, NpArrayT, NpArrayT]:
-    """
-    Decomposes A into P*A=L*U
-    L is lower
-    U is upper
-    P pivot sorting
-    """
+    """Decomposes A into P*A=L*U, L is lower, U is upper, P pivot sorting."""
     nr, nc = ua.shape
     p = pivot(ua)
     a = p.dot(ua)
@@ -172,11 +158,7 @@ def lu_decomposition(ua: NpArrayT) -> typing.Tuple[NpArrayT, NpArrayT, NpArrayT]
 
 
 def invert_lower(lo: NpArrayT) -> NpArrayT:
-    """
-    Calculates the inverse of
-    a lower left triangular square matrix
-    by forward substitution
-    """
+    """Calculate the inverse of a lower left triangular square matrix by forward substitution."""
     nr, nc = lo.shape
     ilo = np.zeros_like(lo)
     for j in range(nc):
@@ -194,9 +176,7 @@ def invert_upper(up: NpArrayT) -> NpArrayT:
 
 
 def approximate_jacobian_function(func: typing.Callable) -> typing.Callable:
-    """
-    returns numerical jacobian function
-    for a given function ff
+    """Return numerical jacobian function for a given function ff.
 
     If func: R^N --> R^M
     then jac:  R^N --> R^(MxN)
@@ -216,9 +196,7 @@ def approximate_jacobian_function(func: typing.Callable) -> typing.Callable:
     """
 
     def jac_func(x: NpArrayT, params: JacobianParamT = None, dx: NpArrayT = None) -> NpArrayT:
-        """
-        Jacobian function of %s
-        """
+        """Jacobian function of %s."""
         nx = x.size
         if dx is None:
             sign = np.sign(x)
@@ -240,9 +218,7 @@ def approximate_jacobian_function(func: typing.Callable) -> typing.Callable:
     return jac_func
 
 
-def gauss_newton_increment_nform(x: NpArrayT, y: NpArrayT,
-                                 k: NpArrayT, xa: NpArrayT,
-                                 sei: NpArrayT, sai: NpArrayT,
+def gauss_newton_increment_nform(x: NpArrayT, y: NpArrayT, k: NpArrayT, xa: NpArrayT, sei: NpArrayT, sai: NpArrayT,
                                  sa: NpArrayT) -> GaussNewtonT:
     """
     input:
@@ -263,7 +239,7 @@ def gauss_newton_increment_nform(x: NpArrayT, y: NpArrayT,
         ret_err_cov:  retrieval error covariance
 
     Equation: 5.8 (with negative sign put into brackets)
-    This variant is a  'n-form' (n = dimension of state)
+    This variant is a 'n-form' (n = dimension of state).
     """
     kt_sei = np.dot(k.T, sei)
     kt_sei_k = (np.dot(kt_sei, k))
@@ -276,9 +252,7 @@ def gauss_newton_increment_nform(x: NpArrayT, y: NpArrayT,
     return nx, incr_x, ret_err_cov_i, ret_err_cov
 
 
-def gauss_newton_increment_mform(x: NpArrayT, y: NpArrayT,
-                                 k: NpArrayT, xa: NpArrayT,
-                                 sei: NpArrayT, sai: NpArrayT,
+def gauss_newton_increment_mform(x: NpArrayT, y: NpArrayT, k: NpArrayT, xa: NpArrayT, sei: NpArrayT, sai: NpArrayT,
                                  sa: NpArrayT) -> GaussNewtonT:
     """
     input:
@@ -299,7 +273,7 @@ def gauss_newton_increment_mform(x: NpArrayT, y: NpArrayT,
         ret_err_cov:  retrieval error covariance
 
     Equation: 5.10 (with negative sign put into brackets)
-    This variant is a  'm-form' (m is Dimension of measurement)
+    This variant is a 'm-form' (m is Dimension of measurement).
     """
     kt_sei = np.dot(k.T, sei)
     kt_sei_k = (np.dot(kt_sei, k))
@@ -317,8 +291,8 @@ def gauss_newton_increment_mform(x: NpArrayT, y: NpArrayT,
 
 
 def check_increment(ix: NpArrayT, sri: NpArrayT, eps: float) -> bool:
-    """
-    see Rodgers for details...
+    """See Rodgers for details...
+
     input:
       ix : increment of x_i+1 = x_i -ix
       sri: inverse of retrieval error co-variance
@@ -326,8 +300,7 @@ def check_increment(ix: NpArrayT, sri: NpArrayT, eps: float) -> bool:
     return np.dot(ix.T, np.dot(sri, ix)) < (eps * ix.size)
 
 
-def gain_aver_cost(x: NpArrayT, y: NpArrayT, k: NpArrayT,
-                   xa: NpArrayT, sei: NpArrayT, sai: NpArrayT,
+def gain_aver_cost(x: NpArrayT, y: NpArrayT, k: NpArrayT, xa: NpArrayT, sei: NpArrayT, sai: NpArrayT,
                    rec: NpArrayT) -> Diagnostic1T:
     """
     input:
@@ -349,8 +322,7 @@ def gain_aver_cost(x: NpArrayT, y: NpArrayT, k: NpArrayT,
     return gain, aver, cost
 
 
-def dof_infocont_retrnoise_smootherrr(sa: NpArrayT, se: NpArrayT,
-                                      gg: NpArrayT, av: NpArrayT) -> Diagnostic2T:
+def dof_infocont_retrnoise_smootherrr(sa: NpArrayT, se: NpArrayT, gg: NpArrayT, av: NpArrayT) -> Diagnostic2T:
     dof = np.trace(av)
     # information content h
     w, v = np.linalg.eigh(av)
@@ -362,15 +334,9 @@ def dof_infocont_retrnoise_smootherrr(sa: NpArrayT, se: NpArrayT,
     return dof, h, sn, sme
 
 
-def internal_optimizer(y: NpArrayT,
-                       func: CallableT, fparam: NpOrAnyT,
-                       jaco: CallableT, jparam: NpOrAnyT,
-                       xa: NpArrayT, fg: NpArrayT,
-                       sei: NpArrayT, sai: NpArrayT,
-                       se: NpArrayT, sa: NpArrayT,
-                       dx: NpOrAnyT,
-                       eps: float, maxiter: int,
-                       full: bool, gnform: str) -> InternalOptimizerT:
+def internal_optimizer(y: NpArrayT, func: CallableT, fparam: NpOrAnyT, jaco: CallableT, jparam: NpOrAnyT, xa: NpArrayT,
+                       fg: NpArrayT, sei: NpArrayT, sai: NpArrayT, se: NpArrayT, sa: NpArrayT, dx: NpOrAnyT, eps: float,
+                       maxiter: int, full: bool, gnform: str) -> InternalOptimizerT:
     """
     y:       measurement
     func:    function to be inverted
@@ -419,12 +385,10 @@ def internal_optimizer(y: NpArrayT,
 
 
 def invert_function(func, **args):
-    """
-    This solves the following equation:
-    y=func(x,params)
-    and returns a function which is effectively
-    the inverse of func
-    x=func⁻¹(y,fparam=params)
+    """This solves the following equation:
+       y=func(x,params)
+       and returns a function which is effectively the inverse of func
+       x=func⁻¹(y,fparam=params).
 
     mandatory INPUT:
        func  = function to be inverted
@@ -456,25 +420,10 @@ def invert_function(func, **args):
     if args['jaco'] is None:
         args['jaco'] = approximate_jacobian_function(func)
 
-    def func_inverse(yy,
-                     fparam=args['fparam'],
-                     jparam=args['jparam'],
-                     ll=args['ll'],
-                     ul=args['ul'],
-                     se=args['se'],
-                     sa=args['sa'],
-                     xa=args['xa'],
-                     dx=args['dx'],
-                     eps=args['eps'],
-                     fg=args['fg'],
-                     jaco=args['jaco'],
-                     maxiter=args['mi'],
-                     full=args['full'],
-                     clip=args['clip'],
-                     gnform=args['gnform']):
-        """
-        Inverse function of *%(name)s*. Estimates the
-        optimal *state*, that explains the measurement *yy*.
+    def func_inverse(yy, fparam=args['fparam'], jparam=args['jparam'], ll=args['ll'], ul=args['ul'], se=args['se'],
+                     sa=args['sa'], xa=args['xa'], dx=args['dx'], eps=args['eps'], fg=args['fg'], jaco=args['jaco'],
+                     maxiter=args['mi'], full=args['full'], clip=args['clip'], gnform=args['gnform']):
+        """Inverse function of *%(name)s*. Estimates the optimal *state*, that explains the measurement *yy*.
 
         Input:
             yy   = measurement
@@ -543,21 +492,8 @@ def invert_function(func, **args):
         else:
             cfunc, cjaco = func, jaco
 
-        result = internal_optimizer(y=yyy,
-                                    xa=xa,
-                                    fg=fg,
-                                    sei=sei,
-                                    sai=sai,
-                                    se=se,
-                                    sa=sa,
-                                    dx=dx,
-                                    eps=eps,
-                                    maxiter=maxiter,
-                                    func=cfunc,
-                                    fparam=fparam,
-                                    jaco=cjaco,
-                                    jparam=jparam,
-                                    full=full,
+        result = internal_optimizer(y=yyy, xa=xa, fg=fg, sei=sei, sai=sai, se=se, sa=sa, dx=dx, eps=eps,
+                                    maxiter=maxiter, func=cfunc, fparam=fparam, jaco=cjaco, jparam=jparam, full=full,
                                     gnform=gnform)
 
         return RESULT(*result)
