@@ -26,11 +26,16 @@
 
 import numpy as np
 from multiprocessing import Pool
+import platform
+from tqdm import tqdm
+
+from sicor.Tools.EnMAP.multiprocessing import initializer
 
 
 def SLIC_segmentation(data_rad_all, n_pca, segs):
-    """Perform superpixel segmentation by searching the image for a handful of geographically and compositionally
-       representative locations. Create spatially-contiguous clusters of similar radiances.
+    """
+    Perform superpixel segmentation by searching the image for a handful of geographically and compositionally
+    representative locations. Create spatially-contiguous clusters of similar radiances.
 
     :param data_rad_all: radiance data array with shape (rows, cols, bands)
     :param n_pca:        number of principle components
@@ -57,29 +62,41 @@ def SLIC_segmentation(data_rad_all, n_pca, segs):
     X_pca = (X - mu) @ d[:, -n_pca:]
     X_pca = X_pca.reshape([rows, cols, n_pca])
 
-    labels = slic(X_pca, n_segments=segs, compactness=cmpct, max_iter=10, sigma=0, multichannel=True,
-                  enforce_connectivity=True, min_size_factor=0.5, max_size_factor=3)
+    labels = slic(image=X_pca,
+                  n_segments=segs,
+                  compactness=cmpct,
+                  max_iter=10,
+                  sigma=0,
+                  multichannel=True,
+                  enforce_connectivity=True,
+                  min_size_factor=0.5,
+                  max_size_factor=3)
+
     lbl = np.unique(labels)
     segs = len(lbl)
 
     return X, segs, labels
 
 
-def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs, labels, land_only, processes):
-    """Apply empirical line solution to infer exact result of remaining spectra.
+def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs, labels, land_only, processes,
+                            disable_progressbars):
+    """
+    Apply empirical line solution to infer exact result of remaining spectra.
 
-    :param X:            flattened radiance data array
-    :param rdn_subset:   radiance data subset
-    :param data_l2a_seg: segmented surface reflectance
-    :param rows:         number of image rows
-    :param cols:         number of image columns
-    :param bands:        number of instrument bands
-    :param segs:         number of segments
-    :param labels:       array of segment labels for each pixel
-    :param land_only:    if True, SICOR is applied to land surfaces only (this may result in edge effects, e.g., at
-                         coastlines); otherwise, all image pixels (land + water) are processed; default: False
-    :param processes:    number of CPUs for multiprocessing
-    :return:             extrapolated surface reflectance for each pixel
+    :param X:                    flattened radiance data array
+    :param rdn_subset:           radiance data subset
+    :param data_l2a_seg:         segmented surface reflectance
+    :param rows:                 number of image rows
+    :param cols:                 number of image columns
+    :param bands:                number of instrument bands
+    :param segs:                 number of segments
+    :param labels:               array of segment labels for each pixel
+    :param land_only:            if True, SICOR is applied to land surfaces only (this may result in edge effects,
+                                 e.g., at coastlines); otherwise, all image pixels (land + water) are processed;
+                                 default: False
+    :param processes:            number of CPUs for multiprocessing
+    :param disable_progressbars: True if progress bars should be disabled; default: False
+    :return:                     extrapolated surface reflectance for each pixel
     """
     from scipy.spatial import KDTree  # import here to avoid static TLS ImportError
 
@@ -106,9 +123,19 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
         unique_labels = np.arange(0, np.max(lbl) + 1 - len(missing_labels), 1)
     else:
         for i in range(segs):
-            locations_subset[i, :] = locations[labels.flat == i, :].mean(axis=0)
+            if np.count_nonzero(segs == 1) == 0:
+                pass
+            else:
+                locations_subset[i, :] = locations[labels.flat == i, :].mean(axis=0)
 
         unique_labels = np.unique(labels)
+        missing_labels = []
+
+        for ii in range(np.max(unique_labels)):
+            if ii not in unique_labels:
+                missing_labels.append(ii)
+
+        unique_labels = np.arange(0, np.max(unique_labels) - len(missing_labels), 1)
 
     tree = KDTree(locations_subset)
 
@@ -116,8 +143,15 @@ def empirical_line_solution(X, rdn_subset, data_l2a_seg, rows, cols, bands, segs
     global _globs
     _globs = dict(tree=tree, locs=locations_subset, k=15, rdn=rdn_subset, data=data_l2a_seg, bands=bands)
 
-    with Pool(processes=processes) as pool:
-        results = pool.map(_compute_coefficients_for_label, unique_labels)
+    if platform.system() == "Windows" or processes == 1:
+        initializer(globals(), _globs)
+        results = []
+        for ii in tqdm(unique_labels, disable=disable_progressbars):
+            (sl, ic) = _compute_coefficients_for_label(ii)
+            results.append((sl, ic))
+    else:
+        with Pool(processes=processes) as pool:
+            results = pool.map(_compute_coefficients_for_label, unique_labels)
 
     slopes, intercepts = np.empty([rows * cols, bands]), np.empty([rows * cols, bands])
 
@@ -145,4 +179,5 @@ def _compute_coefficients_for_label(label_idx):
     label_slopes, label_intercepts = zip(*[linregress(x=_globs['rdn'][:, nn, b],
                                                       y=_globs['data'][:, nn, b])[:2]
                                            for b in range(_globs['bands'])])
+
     return label_slopes, label_intercepts
