@@ -132,7 +132,7 @@ def write_raster_gdal(data, filename, gdal_type=gdal.GDT_UInt16, driver=None, ou
 
             logger.info("Original data shape: %s" % str(data.shape))
             dtype = data.dtype
-            data = np.array(zoom(np.array(data, dtype=np.float), zoom_fac, order=order), dtype=dtype)
+            data = np.array(zoom(np.array(data, dtype=float), zoom_fac, order=order), dtype=dtype)
             logger.info("New data shape: %s" % str(data.shape))
 
     gdal.AllRegister()
