@@ -49,7 +49,7 @@ class CloudMask(S2cB):
             if file_ext == "json":
                 with open(novelty_detector, "r") as fl:
                     nvc, ncv_clf = (lambda nvc_data: (
-                        OneClassSVM(**nvc_data["params"]).fit(np.array(nvc_data["data"], dtype=np.float)),
+                        OneClassSVM(**nvc_data["params"]).fit(np.array(nvc_data["data"], dtype=float)),
                         nvc_data["clf"]
                     ))(json.load(fl))
             elif file_ext == "pkl":
