@@ -36,7 +36,7 @@ def get_tck(x, y, z, kk_default=3, logger=None):
     logger = logger or logging.getLogger(__name__)
     # estimate max number of allowed spline order
     mm = len(x)
-    kk_max = np.int(np.floor(np.sqrt(mm / 2.0) - 1))
+    kk_max = int(np.floor(np.sqrt(mm / 2.0) - 1))
     kk = np.min([kk_default, kk_max])
 
     result = bisplrep(x=x, y=y, z=z, kx=kk, ky=kk, full_output=1)
@@ -315,8 +315,8 @@ final shape: %s, index: %i""" % (band, t2 - t0, t1 - t0, t2 - t1, zoom_fac, str(
             # if lons or lats are missing from metadata -> add from tile info
             self.logger.warning("Missing lon/lats from aux data -> get it from granule info.")
             ti = GranuleInfo(version="lite")[self.tile_name]
-            lats = np.zeros((2, 2), dtype=np.float)
-            lons = np.zeros((2, 2), dtype=np.float)
+            lats = np.zeros((2, 2), dtype=float)
+            lons = np.zeros((2, 2), dtype=float)
             try:
                 for i1, tb in enumerate(["t", "l"]):
                     for i2, lr in enumerate(["l", "r"]):
@@ -363,7 +363,7 @@ final shape: %s, index: %i""" % (band, t2 - t0, t1 - t0, t2 - t1, zoom_fac, str(
 
         to_gb = 1.0 / 1024.0 ** 3
         mem = virtual_memory().total * to_gb
-        arr = np.int(np.prod(np.array(shape, dtype=np.int64)) * np.zeros(1, dtype=dtype).nbytes * to_gb)
+        arr = int(np.prod(np.array(shape, dtype=np.int64)) * np.zeros(1, dtype=dtype).nbytes * to_gb)
 
         if arr < max_mem_frac * mem:
             try:
@@ -527,7 +527,7 @@ final shape: %s, index: %i""" % (band, t2 - t0, t1 - t0, t2 - t1, zoom_fac, str(
         return buf
 
     @staticmethod
-    def get_values_from_xml(leaf, dtype=np.float):
+    def get_values_from_xml(leaf, dtype=float):
         """
         S2 xml helper function
         :param leaf: xml object which is searched for VALUES tag which are then composed into a numpy array
@@ -724,7 +724,7 @@ class s2_snr_model(object):
         df = pd.read_csv(self.s2_snr_csv_file, decimal=",")
         to_band_name = (
             lambda x: x.upper() if len(x) == 3 else "B0" + x[1])  # normalize band names: Bx -> B0x and Byx -> Byx
-        self.snr_parameters = {to_band_name(ll[0]): np.array([l.replace(",", ".") for l in ll[3:6]], dtype=np.float)
+        self.snr_parameters = {to_band_name(ll[0]): np.array([l.replace(",", ".") for l in ll[3:6]], dtype=float)
                                for ll in df.values[2:2 + 13, :]}
         self.rfl_to_rad = rfl_to_rad
 
