@@ -205,7 +205,7 @@ def include_missing_spatial_samplings(data, samplings, order=0, base_key=None):
         assert base_key in data
         base_spatial_sampling = base_key
     base_dtype = data[base_spatial_sampling].dtype
-    base_data = np.array(data[base_spatial_sampling], dtype=np.float)
+    base_data = np.array(data[base_spatial_sampling], dtype=float)
 
     for key in samplings:
         if key not in data:
@@ -223,14 +223,14 @@ def prepare_s2_wv(n_smpl, bands, fo, rho_bounds):
     """
 
     n_params = np.prod(list(n_smpl.values()))
-    points = np.zeros((n_params, len(["spr", "tau_a"] + bands)), dtype=np.float)
-    values = np.zeros(n_params, dtype=np.float)  # cwv
+    points = np.zeros((n_params, len(["spr", "tau_a"] + bands)), dtype=float)
+    values = np.zeros(n_params, dtype=float)  # cwv
 
     params = product(*([np.linspace(rho_bounds[0], rho_bounds[1], n_smpl["rho"])] +
                        [np.linspace(np.min(fo.dims[dim]), np.max(fo.dims[dim]), n_smpl[dim])
                         for dim in ["cwv", "spr", "tau_a"]]))
 
-    pt = np.zeros(np.max(fo.L0["idx"] + 1), dtype=np.float)
+    pt = np.zeros(np.max(fo.L0["idx"] + 1), dtype=float)
 
     ids = {dim: fo.L0["idx"][fo.L0["dims"].index(dim)] for dim in ["cwv", "spr", "tau_a"]}
 
@@ -258,7 +258,7 @@ def get_egl_lut(fo, spr_lim, dim_spr, dim_wv):
     :param dim_wv: Number of cwv values.
     :return: E_DN LUT for different spr and cwv.
     """
-    pt = np.zeros(np.max(fo.L0["idx"] + 1), dtype=np.float)
+    pt = np.zeros(np.max(fo.L0["idx"] + 1), dtype=float)
     ids = {dim: fo.L0["idx"][fo.L0["dims"].index(dim)] for dim in ["cwv", "spr"]}
     egl_lut = np.zeros((dim_spr, dim_wv, len(fo.wvl)))
 
@@ -524,10 +524,10 @@ def prepare_s2_ac(s2spr, s2cwv, s2tau, clear_areas,
     logger = logger or logging.getLogger(__name__)
 
     n_params = np.prod(list(n_smpl.values()))
-    points = np.zeros((n_params, len(n_smpl.keys())), dtype=np.float)
+    points = np.zeros((n_params, len(n_smpl.keys())), dtype=float)
 
-    rfls = np.zeros((n_params, len(bands)), dtype=np.float)
-    rhos = np.zeros(n_params, dtype=np.float)
+    rfls = np.zeros((n_params, len(bands)), dtype=float)
+    rhos = np.zeros(n_params, dtype=float)
 
     spr_min_fo, spr_max_fo = np.min(fo.dims["spr"]), np.max(fo.dims["spr"])
     cwv_min_fo, cwv_max_fo = np.min(fo.dims["cwv"]), np.max(fo.dims["cwv"])
@@ -564,7 +564,7 @@ def prepare_s2_ac(s2spr, s2cwv, s2tau, clear_areas,
                         np.linspace(tau_min, tau_max, n_smpl["tau_a"]),  # tau_a
                         ]))
 
-    pt = np.zeros(np.max(fo.L0["idx"] + 1), dtype=np.float)
+    pt = np.zeros(np.max(fo.L0["idx"] + 1), dtype=float)
     ids = {dim: fo.L0["idx"][fo.L0["dims"].index(dim)] for dim in ["spr", "cwv", "tau_a"]}
 
     for ii, (rho, spr, cwv, tau_a) in enumerate(params):
@@ -591,7 +591,7 @@ def ac_interpolation(iband, band, s2img, s2spr, s2cwv, s2tau, clear_areas, point
     data_ac = np.empty(s2img.data[band].shape, dtype=np.float32)
     data_ac[:] = np.nan
 
-    dd = max(1, np.int(np.sqrt(np.floor(np.prod(data_ac.shape) / max_pixel_processing))))
+    dd = max(1, int(np.sqrt(np.floor(np.prod(data_ac.shape) / max_pixel_processing))))
     for sx, sy in itt2d(shape=data_ac.shape, dd=dd):
         mask = np.logical_and(np.isfinite(s2img.data[band][sx, sy]),
                               clear_areas[s2img.band_spatial_sampling[band]][sx, sy])
@@ -854,7 +854,7 @@ class IO(object):
 
         if output_bands is not None and uncert is not None:
             def mk_conv_error(nodata_value, max_value, dtype):
-                scaling_value = np.int(np.floor((nodata_value - 1) / max_value))
+                scaling_value = int(np.floor((nodata_value - 1) / max_value))
 
                 def conv_scale(x, nodata_value=nodata_value):
                     """Input conversion function."""
@@ -1052,7 +1052,7 @@ class Figs(object):
         :param nodata: value which will be replaced with NaN
         :return:
         """
-        bf = np.array(data, dtype=np.float)
+        bf = np.array(data, dtype=float)
         bf[data == nodata] = np.NaN
         return bf
 
@@ -1063,7 +1063,7 @@ class Figs(object):
         else:
             ar = next(iter(inp.values()))
 
-        d1, d2 = np.array(np.floor(np.array(ar.shape) / self.ss), dtype=np.int)[:2]
+        d1, d2 = np.array(np.floor(np.array(ar.shape) / self.ss), dtype=int)[:2]
         if len(ar.shape) == 2:
             return np.array(ar[::d1, ::d2], dtype=np.float32)
         elif len(ar.shape) == 3:
